diff --git a/docs/en_US/options-query_tool.rst b/docs/en_US/options-query_tool.rst
index 0b557e7..bb3f0af 100644
--- a/docs/en_US/options-query_tool.rst
+++ b/docs/en_US/options-query_tool.rst
@@ -23,6 +23,8 @@ Use the fields on the *Query editor* dialog to specify workspace preferences for
 
 * **Enable Auto ROLLBACK** - Check the box next to *Enable Auto ROLLBACK* to instruct the query tool to execute a ROLLBACK if a query fails.
 
+* **Enable Auto COMMIT** - Check the box next to *Enable Auto COMMIT* to instruct the query tool to enable auto commit after executing the query.
+
 * **Keywords in uppercase** - Check the box next to *Keywords in uppercase* to instruct the Query tool to convert any keywords entered to an uppercase font.
 
 .. image:: images/options-colours.png
diff --git a/pgadmin/frm/frmOptions.cpp b/pgadmin/frm/frmOptions.cpp
index 4b3b1f1..4081319 100644
--- a/pgadmin/frm/frmOptions.cpp
+++ b/pgadmin/frm/frmOptions.cpp
@@ -89,6 +89,7 @@
 #define chkColumnNames				CTRL_CHECKBOX("chkColumnNames")
 #define txtThousandsSeparator       CTRL_TEXT("txtThousandsSeparator")
 #define chkAutoRollback             CTRL_CHECKBOX("chkAutoRollback")
+#define chkAutoCommit               CTRL_CHECKBOX("chkAutoCommit")
 #define chkDoubleClickProperties    CTRL_CHECKBOX("chkDoubleClickProperties")
 #define chkShowNotices			    CTRL_CHECKBOX("chkShowNotices")
 #define cbLanguage                  CTRL_COMBOBOX("cbLanguage")
@@ -303,6 +304,7 @@ frmOptions::frmOptions(frmMain *parent)
 	chkIndicateNull->SetValue(settings->GetIndicateNull());
 	txtThousandsSeparator->SetValue(settings->GetThousandsSeparator());
 	chkAutoRollback->SetValue(settings->GetAutoRollback());
+	chkAutoCommit->SetValue(settings->GetAutoCommit());
 	chkDoubleClickProperties->SetValue(settings->GetDoubleClickProperties());
 	txtDecimalMark->SetValue(settings->GetDecimalMark());
 	chkColumnNames->SetValue(settings->GetColumnNames());
@@ -670,6 +672,7 @@ void frmOptions::OnOK(wxCommandEvent &ev)
 	settings->SetColumnNames(chkColumnNames->GetValue());
 	settings->SetThousandsSeparator(txtThousandsSeparator->GetValue());
 	settings->SetAutoRollback(chkAutoRollback->GetValue());
+	settings->SetAutoCommit(chkAutoCommit->GetValue());
 	settings->SetDoubleClickProperties(chkDoubleClickProperties->GetValue());
 	settings->SetShowNotices(chkShowNotices->GetValue());
 
diff --git a/pgadmin/frm/frmQuery.cpp b/pgadmin/frm/frmQuery.cpp
index 23ec45b..5a2bace 100644
--- a/pgadmin/frm/frmQuery.cpp
+++ b/pgadmin/frm/frmQuery.cpp
@@ -121,6 +121,7 @@ BEGIN_EVENT_TABLE(frmQuery, pgFrame)
 	EVT_MENU(MNU_EXPLAINANALYZE,    frmQuery::OnExplain)
 	EVT_MENU(MNU_CANCEL,            frmQuery::OnCancel)
 	EVT_MENU(MNU_AUTOROLLBACK,      frmQuery::OnAutoRollback)
+	EVT_MENU(MNU_AUTOCOMMIT,        frmQuery::OnAutoCommit)
 	EVT_MENU(MNU_CONTENTS,          frmQuery::OnContents)
 	EVT_MENU(MNU_HELP,              frmQuery::OnHelp)
 	EVT_MENU(MNU_CLEARHISTORY,      frmQuery::OnClearHistory)
@@ -316,6 +317,7 @@ frmQuery::frmQuery(frmMain *form, const wxString &_title, pgConn *_conn, const w
 	queryMenu->Append(MNU_CLEARHISTORY, _("Clear history"), _("Clear history window."));
 	queryMenu->AppendSeparator();
 	queryMenu->Append(MNU_AUTOROLLBACK, _("&Auto-Rollback"), _("Rollback the current transaction if an error is detected"), wxITEM_CHECK);
+	queryMenu->Append(MNU_AUTOCOMMIT, _("&Auto-Commit"), _("Auto commit the cuurent transaction"), wxITEM_CHECK);
 	queryMenu->AppendSeparator();
 	queryMenu->Append(MNU_CANCEL, _("&Cancel\tAlt-Break"), _("Cancel query"));
 	menuBar->Append(queryMenu, _("&Query"));
@@ -562,6 +564,10 @@ frmQuery::frmQuery(frmMain *form, const wxString &_title, pgConn *_conn, const w
 	settings->Read(wxT("frmQuery/AutoRollback"), &bVal, false);
 	queryMenu->Check(MNU_AUTOROLLBACK, bVal);
 
+	// Auto-commit
+	settings->Read(wxT("frmQuery/AutoCommit"), &bVal, true);
+	queryMenu->Check(MNU_AUTOCOMMIT, bVal);
+
 	// Auto indent
 	settings->Read(wxT("frmQuery/AutoIndent"), &bVal, true);
 	editMenu->Check(MNU_AUTOINDENT, bVal);
@@ -823,6 +829,12 @@ void frmQuery::OnAutoRollback(wxCommandEvent &event)
 	settings->WriteBool(wxT("frmQuery/AutoRollback"), queryMenu->IsChecked(MNU_AUTOROLLBACK));
 }
 
+void frmQuery::OnAutoCommit(wxCommandEvent &event)
+{
+	queryMenu->Check(MNU_AUTOCOMMIT, event.IsChecked());
+
+	settings->WriteBool(wxT("frmQuery/AutoCommit"), queryMenu->IsChecked(MNU_AUTOCOMMIT));
+}
 
 void frmQuery::OnAutoIndent(wxCommandEvent &event)
 {
@@ -2486,6 +2498,9 @@ void frmQuery::execQuery(const wxString &query, int resultToRetrieve, bool singl
 	startTimeQuery = wxGetLocalTimeMillis();
 	timer.Start(10);
 
+	if (!queryMenu->IsChecked(MNU_AUTOCOMMIT) && conn->GetTxStatus() == PQTRANS_IDLE && !CommandNoBegin(query))
+		conn->ExecuteVoid(wxT("BEGIN;"));
+
 	if (sqlResult->Execute(query, resultToRetrieve, this, QUERY_COMPLETE, qi) >= 0)
 	{
 		// Return and wait for the result
@@ -2495,6 +2510,177 @@ void frmQuery::execQuery(const wxString &query, int resultToRetrieve, bool singl
 	completeQuery(false, false, false);
 }
 
+bool frmQuery::CommandNoBegin(wxString query)
+{
+	int	wordlen = 0;
+
+	query = query.Trim(false);
+
+	/*
+	 * Check word length (since "beginx" is not "begin").
+	 */
+	while(wxIsalpha(query.GetChar(wordlen)))
+		wordlen++;
+
+	/*
+	 * Transaction control commands.  These should include every keyword that
+	 * gives rise to a TransactionStmt in the backend grammar, except for the
+	 * savepoint-related commands.
+	 *
+	 * (We assume that START must be START TRANSACTION, since there is
+	 * presently no other "START foo" command.)
+	 */
+	wxString keyword = query.SubString(0, wordlen-1);
+	if (wordlen == 5 && keyword.CmpNoCase(wxT("abort")) == 0)
+		return true;
+	if (wordlen == 5 && keyword.CmpNoCase(wxT("begin")) == 0)
+		return true;
+	if (wordlen == 5 && keyword.CmpNoCase(wxT("start")) == 0)
+		return true;
+	if (wordlen == 6 && keyword.CmpNoCase(wxT("commit")) == 0)
+		return true;
+	if (wordlen == 3 && keyword.CmpNoCase(wxT("end")) == 0)
+		return true;
+	if (wordlen == 8 && keyword.CmpNoCase(wxT("rollback")) == 0)
+		return true;
+	if (wordlen == 7 && keyword.CmpNoCase(wxT("prepare")) == 0)
+	{
+		/* PREPARE TRANSACTION is a TC command, PREPARE foo is not */
+		query = query.SubString(keyword.Length(),query.Length()-1);
+		query = query.Trim(false);
+
+		wordlen = 0;
+		while(wxIsalpha(query.GetChar(wordlen)))
+			wordlen++;
+		keyword = query.SubString(0, wordlen-1);
+
+		if (wordlen == 11 && keyword.CmpNoCase(wxT("transaction")) == 0)
+			return true;
+		return false;
+	}
+
+	/*
+	 * Commands not allowed within transactions.  The statements checked for
+	 * here should be exactly those that call PreventTransactionChain() in the
+	 * backend.
+	 */
+	if (wordlen == 6 && keyword.CmpNoCase(wxT("vacuum")) == 0)
+		return true;
+	if (wordlen == 7 && keyword.CmpNoCase(wxT("cluster")) == 0)
+	{
+		/* CLUSTER with any arguments is allowed in transactions */
+		query = query.SubString(keyword.Length(),query.Length()-1);
+		query = query.Trim(false);
+
+		if(wxIsalpha(((wxChar)query.at(0))))
+			return false;		/* has additional words */
+		return true;			/* it's CLUSTER without arguments */
+	}
+
+	if (wordlen == 6 && keyword.CmpNoCase(wxT("create")) == 0)
+	{
+		query = query.SubString(keyword.Length(),query.Length()-1);
+		query = query.Trim(false);
+
+		wordlen = 0;
+		while(wxIsalpha(query.GetChar(wordlen)))
+			wordlen++;
+		keyword = query.SubString(0, wordlen-1);
+
+		if (wordlen == 8 && keyword.CmpNoCase(wxT("database")) == 0)
+			return true;
+		if (wordlen == 10 && keyword.CmpNoCase(wxT("tablespace")) == 0)
+			return true;
+
+		/* CREATE [UNIQUE] INDEX CONCURRENTLY isn't allowed in xacts */
+		if (wordlen == 6 && keyword.CmpNoCase(wxT("cluster")) == 0)
+		{
+			query = query.SubString(keyword.Length(),query.Length()-1);
+			query = query.Trim(false);
+
+			wordlen = 0;
+			while(wxIsalpha(query.GetChar(wordlen)))
+				wordlen++;
+			keyword = query.SubString(0, wordlen-1);
+		}
+
+		if (wordlen == 5 &&  keyword.CmpNoCase(wxT("index")) == 0)
+		{
+			query = query.SubString(keyword.Length(),query.Length()-1);
+			query = query.Trim(false);
+
+			wordlen = 0;
+			while(wxIsalpha(query.GetChar(wordlen)))
+				wordlen++;
+			keyword = query.SubString(0, wordlen-1);
+
+			if (wordlen == 12 &&  keyword.CmpNoCase(wxT("concurrently")) == 0)
+				return true;
+		}
+
+		return false;
+	}
+
+	if (wordlen == 5 &&  keyword.CmpNoCase(wxT("alter")) == 0)
+	{
+		query = query.SubString(keyword.Length(),query.Length()-1);
+		query = query.Trim(false);
+
+		wordlen = 0;
+		while(wxIsalpha(query.GetChar(wordlen)))
+			wordlen++;
+		keyword = query.SubString(0, wordlen-1);
+
+		/* ALTER SYSTEM isn't allowed in xacts */
+		if (wordlen == 6 && keyword.CmpNoCase(wxT("system")) == 0)
+			return true;
+
+		return false;
+	}
+
+	/*
+	 * Note: these tests will match DROP SYSTEM and REINDEX TABLESPACE, which
+	 * aren't really valid commands so we don't care much. The other four
+	 * possible matches are correct.
+	 */
+	if ((wordlen == 4 && keyword.CmpNoCase(wxT("drop")) == 0) ||
+		(wordlen == 7 && keyword.CmpNoCase(wxT("reindex")) == 0))
+	{
+		query = query.SubString(keyword.Length(),query.Length()-1);
+		query = query.Trim(false);
+
+		wordlen = 0;
+		while(wxIsalpha(query.GetChar(wordlen)))
+			wordlen++;
+		keyword = query.SubString(0, wordlen-1);
+
+		if (wordlen == 8 && keyword.CmpNoCase(wxT("database")) == 0)
+			return true;
+		if (wordlen == 6 && keyword.CmpNoCase(wxT("system")) == 0)
+			return true;
+		if (wordlen == 10 && keyword.CmpNoCase(wxT("tablespace")) == 0)
+			return true;
+		return false;
+	}
+
+	/* DISCARD ALL isn't allowed in xacts, but other variants are allowed. */
+	if (wordlen == 7 && keyword.CmpNoCase(wxT("discard")) == 0)
+	{
+		query = query.SubString(keyword.Length(),query.Length()-1);
+		query = query.Trim(false);
+
+		wordlen = 0;
+		while(wxIsalpha(query.GetChar(wordlen)))
+			wordlen++;
+		keyword = query.SubString(0, wordlen-1);
+
+		if (wordlen == 3 && keyword.CmpNoCase(wxT("all")) == 0)
+			return true;
+		return false;
+	}
+
+	return false;
+}
 
 // When the query completes, it raises an event which we process here.
 void frmQuery::OnQueryComplete(pgQueryResultEvent &ev)
@@ -2839,7 +3025,7 @@ void frmQuery::completeQuery(bool done, bool explain, bool verbose)
 	msgHistory->ShowPosition(0);
 
 	// If the transaction aborted for some reason, issue a rollback to cleanup.
-	if (settings->GetAutoRollback() && conn->GetTxStatus() == PGCONN_TXSTATUS_INERROR)
+	if (queryMenu->IsChecked(MNU_AUTOROLLBACK) && conn->GetTxStatus() == PGCONN_TXSTATUS_INERROR)
 		conn->ExecuteVoid(wxT("ROLLBACK;"));
 
 	setTools(false);
diff --git a/pgadmin/include/frm/frmQuery.h b/pgadmin/include/frm/frmQuery.h
index c698370..47666f8 100644
--- a/pgadmin/include/frm/frmQuery.h
+++ b/pgadmin/include/frm/frmQuery.h
@@ -199,6 +199,7 @@ private:
 	void OnRedo(wxCommandEvent &event);
 	void OnSaveHistory(wxCommandEvent &event);
 	void OnAutoRollback(wxCommandEvent &event);
+	void OnAutoCommit(wxCommandEvent &event);
 	void OnChangeConnection(wxCommandEvent &ev);
 	void OnClearHistory(wxCommandEvent &event);
 	void OnActivate(wxActivateEvent &event);
@@ -239,6 +240,7 @@ private:
 	void execQuery(const wxString &query, int resultToRetrieve = 0, bool singleResult = false, const int queryOffset = 0, bool toFile = false, bool explain = false, bool verbose = false);
 	void OnQueryComplete(pgQueryResultEvent &ev);
 	void completeQuery(bool done, bool explain, bool verbose);
+	bool CommandNoBegin(wxString query);
 	void OnScriptComplete(wxCommandEvent &ev);
 	void setTools(const bool running);
 	void showMessage(const wxString &msg, const wxString &msgShort = wxT(""));
diff --git a/pgadmin/include/frm/menu.h b/pgadmin/include/frm/menu.h
index fb20b60..4d0f757 100644
--- a/pgadmin/include/frm/menu.h
+++ b/pgadmin/include/frm/menu.h
@@ -71,6 +71,7 @@ enum
 	MNU_BUFFERS,
 	MNU_TIMING,
 	MNU_AUTOROLLBACK,
+	MNU_AUTOCOMMIT,
 	MNU_CLEARHISTORY,
 	MNU_SAVEHISTORY,
 	MNU_CHECKALIVE,
diff --git a/pgadmin/include/utils/sysSettings.h b/pgadmin/include/utils/sysSettings.h
index eb11213..c1faf81 100644
--- a/pgadmin/include/utils/sysSettings.h
+++ b/pgadmin/include/utils/sysSettings.h
@@ -374,6 +374,16 @@ public:
 	{
 		WriteBool(wxT("frmQuery/AutoRollback"), newval);
 	}
+	bool GetAutoCommit() const
+	{
+		bool b;
+		Read(wxT("frmQuery/AutoCommit"), &b, true);
+		return b;
+	}
+	void SetAutoCommit(const bool newval)
+	{
+		WriteBool(wxT("frmQuery/AutoCommit"), newval);
+	}
 	wxString GetDecimalMark() const
 	{
 		wxString s;
diff --git a/pgadmin/ui/frmOptions.xrc b/pgadmin/ui/frmOptions.xrc
index a57b0ce..ab8d7a5 100644
--- a/pgadmin/ui/frmOptions.xrc
+++ b/pgadmin/ui/frmOptions.xrc
@@ -1,9 +1,6 @@
 <?xml version="1.0" encoding="ISO-8859-1"?>
 <resource>
   <object class="wxDialog" name="frmOptions">
-    <title>Options</title>
-    <size>480,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
@@ -14,23 +11,23 @@
           <growablerows>0</growablerows>
           <growablecols>1</growablecols>
           <object class="sizeritem">
-		        <object class="ctlTree" name="menus">
-			        <size>100,225d</size>
+            <object class="ctlTree" name="menus">
+              <size>100,225d</size>
               <style>wxTR_HAS_BUTTONS|wxSIMPLE_BORDER|wxTR_HIDE_ROOT</style>
             </object>
             <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
             <border>3</border>
           </object>
           <object class="sizeritem">
-		        <object class="wxFlexGridSizer">
+            <object class="wxFlexGridSizer">
               <cols>1</cols>
               <vgap>5</vgap>
               <hgap>5</hgap>
               <growablerows>0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15</growablerows>
               <growablecols>0</growablecols>
               <object class="sizeritem">
-			          <object class="wxPanel" name="pnlMiscHelpPath">
-				          <hidden>1</hidden>
+                <object class="wxPanel" name="pnlMiscHelpPath">
+                  <hidden>1</hidden>
                   <object class="wxFlexGridSizer">
                     <cols>2</cols>
                     <vgap>5</vgap>
@@ -92,8 +89,8 @@
                 <border>4</border>
               </object>
               <object class="sizeritem">
-			          <object class="wxPanel" name="pnlMiscUI">
-				          <hidden>1</hidden>
+                <object class="wxPanel" name="pnlMiscUI">
+                  <hidden>1</hidden>
                   <object class="wxFlexGridSizer">
                     <cols>2</cols>
                     <vgap>5</vgap>
@@ -132,8 +129,8 @@
                 <border>4</border>
               </object>
               <object class="sizeritem">
-			          <object class="wxPanel" name="pnlBrowserDisplay">
-				          <hidden>1</hidden>
+                <object class="wxPanel" name="pnlBrowserDisplay">
+                  <hidden>1</hidden>
                   <object class="wxFlexGridSizer">
                     <cols>1</cols>
                     <vgap>5</vgap>
@@ -167,8 +164,8 @@
                 <border>4</border>
               </object>
               <object class="sizeritem">
-			          <object class="wxPanel" name="pnlBrowserProperties">
-				          <hidden>1</hidden>
+                <object class="wxPanel" name="pnlBrowserProperties">
+                  <hidden>1</hidden>
                   <object class="wxFlexGridSizer">
                     <cols>2</cols>
                     <vgap>5</vgap>
@@ -262,7 +259,7 @@
                     </object>
                     <object class="sizeritem">
                       <object class="wxStaticText">
-                        <label></label>
+                        <label/>
                       </object>
                       <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
@@ -276,7 +273,7 @@
                     </object>
                     <object class="sizeritem">
                       <object class="wxStaticText">
-                        <label></label>
+                        <label/>
                       </object>
                       <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
@@ -295,7 +292,7 @@
               </object>
               <object class="sizeritem">
                 <object class="wxPanel" name="pnlBrowserMisc">
-				          <hidden>1</hidden>
+                  <hidden>1</hidden>
                   <object class="wxFlexGridSizer">
                     <cols>1</cols>
                     <vgap>5</vgap>
@@ -342,7 +339,7 @@
                     <object class="sizeritem">
                       <object class="wxCheckBox" name="chkShowUsersForPrivileges">
                         <label>Show users for privileges</label>
-                      <checked>0</checked>
+                        <checked>0</checked>
                       </object>
                       <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
@@ -388,201 +385,216 @@
                           <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                           <border>4</border>
                         </object>
-
                       </object>
                       <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
                     </object>
                   </object>
                 </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlQueryToolEditor">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>2</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>1</growablecols>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stSqlFont">
-                    <label>Font</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxFontPickerCtrl" name="pickerSqlFont"/>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="lblMaxColSize">
-                    <label>Max. characters per column</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxTextCtrl" name="txtMaxColSize">
-                    <value>256</value>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stIndent">
-                    <label>Indent characters</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxTextCtrl" name="txtIndent"/>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stSpacesForTabs">
-                    <label>Use spaces instead of tabs</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkSpacesForTabs">
-                    <label></label>
-                    <style></style>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stStickySql">
-                    <label>Copy SQL from main window to query tool</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkStickySql">
-                    <label></label>
-                    <checked>1</checked>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stAutoRollback">
-                    <label>Enable Auto ROLLBACK</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkAutoRollback">
-                    <label></label>
-                    <checked>0</checked>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                  <object class="sizeritem">
-                    <object class="wxStaticText" name="stKeywordInUppercase">
-                      <label>Keywords in uppercase</label>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
+              </object>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlQueryToolEditor">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>1</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stSqlFont">
+                        <label>Font</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
                     </object>
-                    <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                    <border>4</border>
-                  </object>
-                  <object class="sizeritem">
-                    <object class="wxCheckBox" name="chkKeywordsInUppercase">
-                      <label></label>
+                    <object class="sizeritem">
+                      <object class="wxFontPickerCtrl" name="pickerSqlFont"/>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="lblMaxColSize">
+                        <label>Max. characters per column</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtMaxColSize">
+                        <value>256</value>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stIndent">
+                        <label>Indent characters</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtIndent"/>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stSpacesForTabs">
+                        <label>Use spaces instead of tabs</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkSpacesForTabs">
+                        <label/>
+                        <style/>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stStickySql">
+                        <label>Copy SQL from main window to query tool</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkStickySql">
+                        <label/>
+                        <checked>1</checked>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stAutoRollback">
+                        <label>Enable Auto ROLLBACK</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkAutoRollback">
+                        <label/>
+                        <checked>0</checked>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stAutoCommit">
+                        <label>Enable Auto COMMIT</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkAutoCommit"/>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
                     </object>
-                    <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                    <border>4</border>
-                  </object>                  
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stKeywordInUppercase">
+                        <label>Keywords in uppercase</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkKeywordsInUppercase">
+                        <label/>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                  </object>
                 </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlQueryToolColours">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>1</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>0</growablecols>
-                <object class="sizeritem">
-                  <object class="wxStaticBoxSizer">
-                    <label>Foreground/Background</label>
-                    <orient>wxVERTICAL</orient>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlQueryToolColours">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>1</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>0</growablecols>
                     <object class="sizeritem">
-                      <object class="wxFlexGridSizer">
-                        <cols>3</cols>
-                        <vgap>4</vgap>
-                        <hgap>4</hgap>
-                        <growablecols>0,1</growablecols>
-                        <object class="sizeritem">
-                          <object class="wxCheckBox" name="chkSQLUseSystemBackgroundColour">
-                            <label>Use system background color</label>
-                            <style></style>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLCustomBackgroundColour">
-                            <label>Custom background</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
+                      <object class="wxStaticBoxSizer">
+                        <label>Foreground/Background</label>
+                        <orient>wxVERTICAL</orient>
                         <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLBackgroundColour">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxCheckBox" name="chkSQLUseSystemForegroundColour">
-                            <label>Use system foreground color</label>
-                            <style></style>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLCustomForegroundColour">
-                            <label>Custom foreground</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLForegroundColour">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="spacer">
-                          <size>0,0d</size>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLMarginBackgroundColour">
-                            <label>Margin background</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLMarginBackgroundColour">
-                            <size>70,12d</size>
+                          <object class="wxFlexGridSizer">
+                            <cols>3</cols>
+                            <vgap>4</vgap>
+                            <hgap>4</hgap>
+                            <growablecols>0,1</growablecols>
+                            <object class="sizeritem">
+                              <object class="wxCheckBox" name="chkSQLUseSystemBackgroundColour">
+                                <label>Use system background color</label>
+                                <style/>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLCustomBackgroundColour">
+                                <label>Custom background</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLBackgroundColour">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxCheckBox" name="chkSQLUseSystemForegroundColour">
+                                <label>Use system foreground color</label>
+                                <style/>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLCustomForegroundColour">
+                                <label>Custom foreground</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLForegroundColour">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="spacer">
+                              <size>0,0d</size>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLMarginBackgroundColour">
+                                <label>Margin background</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLMarginBackgroundColour">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
                           </object>
                           <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                           <border>4</border>
@@ -591,539 +603,535 @@
                       <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
                     </object>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticBoxSizer">
-                    <label>Caret</label>
-                    <orient>wxVERTICAL</orient>
                     <object class="sizeritem">
-                      <object class="wxFlexGridSizer">
-                        <cols>2</cols>
-                        <vgap>4</vgap>
-                        <hgap>4</hgap>
-                        <growablecols>0,1</growablecols>
+                      <object class="wxStaticBoxSizer">
+                        <label>Caret</label>
+                        <orient>wxVERTICAL</orient>
                         <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLCaretColour">
-                            <label>Caret</label>
+                          <object class="wxFlexGridSizer">
+                            <cols>2</cols>
+                            <vgap>4</vgap>
+                            <hgap>4</hgap>
+                            <growablecols>0,1</growablecols>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLCaretColour">
+                                <label>Caret</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLCaretColour">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
                           </object>
                           <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                           <border>4</border>
                         </object>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticBoxSizer">
+                        <label>SQL Syntax Highlighting</label>
+                        <orient>wxVERTICAL</orient>
                         <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLCaretColour">
-                            <size>70,12d</size>
+                          <object class="wxFlexGridSizer">
+                            <cols>4</cols>
+                            <vgap>4</vgap>
+                            <hgap>4</hgap>
+                            <growablecols>0,2</growablecols>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLColour1">
+                                <label>Multiline comment</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLColour1">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLColour6">
+                                <label>Double quoted string</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLColour6">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLColour2">
+                                <label>Single line comment</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLColour2">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLColour7">
+                                <label>Single quoted string</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLColour7">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLColour3">
+                                <label>SQL doc</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLColour3">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLColour10">
+                                <label>Operator</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLColour10">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLColour4">
+                                <label>Number</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLColour4">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLColour11">
+                                <label>Identifier</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLColour11">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="wxStaticText" name="stSQLColour5">
+                                <label>Keyword</label>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
+                            <object class="sizeritem">
+                              <object class="ctlColourPicker" name="pickerSQLColour5">
+                                <size>70,12d</size>
+                              </object>
+                              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                              <border>4</border>
+                            </object>
                           </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
+                          <flag>wxEXPAND|wxALIGN_CENTRE|wxALL</flag>
+                          <border>3</border>
                         </object>
                       </object>
                       <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
                     </object>
                   </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
                 </object>
-                <object class="sizeritem">
-                  <object class="wxStaticBoxSizer">
-                    <label>SQL Syntax Highlighting</label>
-                    <orient>wxVERTICAL</orient>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
+              </object>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlQueryToolResults">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>1</growablecols>
                     <object class="sizeritem">
-                      <object class="wxFlexGridSizer">
-                        <cols>4</cols>
-                        <vgap>4</vgap>
-                        <hgap>4</hgap>
-                        <growablecols>0,2</growablecols>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLColour1">
-                            <label>Multiline comment</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLColour1">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLColour6">
-                            <label>Double quoted string</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLColour6">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLColour2">
-                            <label>Single line comment</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLColour2">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLColour7">
-                            <label>Single quoted string</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLColour7">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLColour3">
-                            <label>SQL doc</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLColour3">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLColour10">
-                            <label>Operator</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLColour10">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLColour4">
-                            <label>Number</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLColour4">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLColour11">
-                            <label>Identifier</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLColour11">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="wxStaticText" name="stSQLColour5">
-                            <label>Keyword</label>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
-                        <object class="sizeritem">
-                          <object class="ctlColourPicker" name="pickerSQLColour5">
-                            <size>70,12d</size>
-                          </object>
-                          <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                          <border>4</border>
-                        </object>
+                      <object class="wxStaticText" name="stCopyQuote">
+                        <label>Result copy quoting</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbCopyQuote">
+                        <content>
+                          <item>None</item>
+                          <item>Strings</item>
+                          <item>All</item>
+                        </content>
+                        <style>wxCB_READONLY|wxCB_DROPDOWN</style>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stCopyQuoteChar">
+                        <label>Result copy quote character</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbCopyQuoteChar">
+                        <content>
+                          <item>&quot;</item>
+                          <item>'</item>
+                        </content>
+                        <style>wxCB_DROPDOWN</style>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stCopySeparator">
+                        <label>Result copy field separator</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxComboBox" name="cbCopySeparator">
+                        <content>
+                          <item>;</item>
+                          <item>,</item>
+                          <item>|</item>
+                          <item>Tab</item>
+                        </content>
+                        <style>wxCB_DROPDOWN</style>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stIndicateNull">
+                        <label>Show NULL values as &lt;NULL&gt;</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkIndicateNull">
+                        <label/>
+                        <checked>0</checked>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stThousandsSeparator">
+                        <label>Thousands separator</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtThousandsSeparator">
+                        <label/>
+                        <checked>0</checked>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stDecimalMark">
+                        <label>Decimal mark</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtDecimalMark">
+                        <label/>
+                        <checked>0</checked>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stColumnNames">
+                        <label>Copy column names</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkColumnNames">
+                        <label/>
+                        <checked>0</checked>
                       </object>
-                      <flag>wxEXPAND|wxALIGN_CENTRE|wxALL</flag>
-                      <border>3</border>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
                     </object>
                   </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
                 </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlQueryToolResults">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>2</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>1</growablecols>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stCopyQuote">
-                    <label>Result copy quoting</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxComboBox" name="cbCopyQuote">
-                    <content>
-                      <item>None</item>
-                      <item>Strings</item>
-                      <item>All</item>
-                    </content>
-                    <style>wxCB_READONLY|wxCB_DROPDOWN</style>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stCopyQuoteChar">
-                    <label>Result copy quote character</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxComboBox" name="cbCopyQuoteChar">
-                    <content>
-                      <item>&quot;</item>
-                      <item>'</item>
-                    </content>
-                    <style>wxCB_DROPDOWN</style>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stCopySeparator">
-                    <label>Result copy field separator</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxComboBox" name="cbCopySeparator">
-                    <content>
-                      <item>;</item>
-                      <item>,</item>
-                      <item>|</item>
-                      <item>Tab</item>
-                    </content>
-                    <style>wxCB_DROPDOWN</style>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stIndicateNull">
-                    <label>Show NULL values as &lt;NULL&gt;</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkIndicateNull">
-                    <label></label>
-                    <checked>0</checked>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stThousandsSeparator">
-                    <label>Thousands separator</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxTextCtrl" name="txtThousandsSeparator">
-                    <label></label>
-                    <checked>0</checked>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stDecimalMark">
-                    <label>Decimal mark</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxTextCtrl" name="txtDecimalMark">
-                    <label></label>
-                    <checked>0</checked>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stColumnNames">
-                    <label>Copy column names</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkColumnNames">
-                    <label></label>
-                    <checked>0</checked>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlQueryToolFiles">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>1</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>0</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkUnicodeFile">
+                        <label>Read and write Unicode UTF-8 files</label>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkWriteBOM">
+                        <label>Write BOM for UTF files</label>
+                        <checked>1</checked>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkAskSaveConfirm">
+                        <label>Do not prompt for unsaved files on exit</label>
+                        <checked>0</checked>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>                  
                 </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlQueryToolFiles">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>1</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>0</growablecols>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkUnicodeFile">
-                    <label>Read and write Unicode UTF-8 files</label>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkWriteBOM">
-                    <label>Write BOM for UTF files</label>
-                    <checked>1</checked>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkAskSaveConfirm">
-                    <label>Do not prompt for unsaved files on exit</label>
-                    <checked>0</checked>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlQueryToolFavourites">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>1</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stFavouritesFile">
+                        <label>Favourites file path</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxFilePickerCtrl" name="pickerFavouritesFile">
+                        <message>Select file to store favourites queries</message>
+                        <style>wxFLP_OPEN|wxFLP_USE_TEXTCTRL</style>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
                 </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlQueryToolFavourites">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>2</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>1</growablecols>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stFavouritesFile">
-                    <label>Favourites file path</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxFilePickerCtrl" name="pickerFavouritesFile">
-                    <message>Select file to store favourites queries</message>
-                    <style>wxFLP_OPEN|wxFLP_USE_TEXTCTRL</style>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlQueryToolMacros">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>1</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stMacrosFile">
+                        <label>Macros file path</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxFilePickerCtrl" name="pickerMacrosFile">
+                        <message>Select file to store macros</message>
+                        <style>wxFLP_OPEN|wxFLP_USE_TEXTCTRL</style>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
                 </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlQueryToolMacros">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>2</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>1</growablecols>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stMacrosFile">
-                    <label>Macros file path</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxFilePickerCtrl" name="pickerMacrosFile">
-                    <message>Select file to store macros</message>
-                    <style>wxFLP_OPEN|wxFLP_USE_TEXTCTRL</style>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlQueryToolHistoryFile">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>1</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stHistoryFile">
+                        <label>History file path</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxFilePickerCtrl" name="pickerHistoryFile">
+                        <message>Select file to store queries history</message>
+                        <style>wxFLP_OPEN|wxFLP_USE_TEXTCTRL</style>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="lblHistoryMaxQueries">
+                        <label>Maximum queries to store in history</label>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtHistoryMaxQueries">
+                        <value>10</value>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="lblHistoryMaxQuerySize">
+                        <label>Maximum size of a stored query (in bytes)</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtHistoryMaxQuerySize">
+                        <value>100</value>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
                 </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlQueryToolHistoryFile">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>2</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>1</growablecols>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="stHistoryFile">
-                    <label>History file path</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxFilePickerCtrl" name="pickerHistoryFile">
-                    <message>Select file to store queries history</message>
-                    <style>wxFLP_OPEN|wxFLP_USE_TEXTCTRL</style>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="lblHistoryMaxQueries">
-                    <label>Maximum queries to store in history</label>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxTextCtrl" name="txtHistoryMaxQueries">
-                    <value>10</value>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="lblHistoryMaxQuerySize">
-                    <label>Maximum size of a stored query (in bytes)</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxTextCtrl" name="txtHistoryMaxQuerySize">
-                    <value>100</value>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlServerStatus">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>0</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stIdleProcessColour">
+                        <label>Idle Process Colour</label>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="ctlColourPicker" name="pickerIdleProcessColour">
+                        <size>70,12d</size>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stActiveProcessColour">
+                        <label>Active Process Colour</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="ctlColourPicker" name="pickerActiveProcessColour">
+                        <size>70,12d</size>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stSlowProcessColour">
+                        <label>Slow Process Colour</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="ctlColourPicker" name="pickerSlowProcessColour">
+                        <size>70,12d</size>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stBlockedProcessColour">
+                        <label>Blocked Process Colour</label>
+                      </object>
+                      <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="ctlColourPicker" name="pickerBlockedProcessColour">
+                        <size>70,12d</size>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                </object>
-              </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlServerStatus">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>2</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>0</growablecols>
-					<object class="sizeritem">
-					  <object class="wxStaticText" name="stIdleProcessColour">
-						<label>Idle Process Colour</label>
-					  </object>
-					  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-					  <border>4</border>
-					</object>
-					<object class="sizeritem">
-					  <object class="ctlColourPicker" name="pickerIdleProcessColour">
-						<size>70,12d</size>
-					  </object>
-					  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-					  <border>4</border>
-					</object>
-					<object class="sizeritem">
-					  <object class="wxStaticText" name="stActiveProcessColour">
-						<label>Active Process Colour</label>
-					  </object>
-					  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-					  <border>4</border>
-					</object>
-					<object class="sizeritem">
-					  <object class="ctlColourPicker" name="pickerActiveProcessColour">
-						<size>70,12d</size>
-					  </object>
-					  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-					  <border>4</border>
-					</object>
-					<object class="sizeritem">
-					  <object class="wxStaticText" name="stSlowProcessColour">
-						<label>Slow Process Colour</label>
-					  </object>
-					  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-					  <border>4</border>
-					</object>
-					<object class="sizeritem">
-					  <object class="ctlColourPicker" name="pickerSlowProcessColour">
-						<size>70,12d</size>
-					  </object>
-					  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-					  <border>4</border>
-					</object>
-					<object class="sizeritem">
-					  <object class="wxStaticText" name="stBlockedProcessColour">
-						<label>Blocked Process Colour</label>
-					  </object>
-					  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-					  <border>4</border>
-					</object>
-					<object class="sizeritem">
-					  <object class="ctlColourPicker" name="pickerBlockedProcessColour">
-						<size>70,12d</size>
-					  </object>
-					  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-					  <border>4</border>
-					</object>
                 </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
+              <object class="sizeritem">
                 <object class="wxPanel" name="pnlDatabaseDesigner">
                   <hidden>1</hidden>
                   <object class="wxFlexGridSizer">
@@ -1154,111 +1162,111 @@
                       <border>4</border>
                     </object>
                   </object>
-			  <object class="wxPanel" name="pnlPgAgent">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>2</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>1</growablecols>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="lblMaxRows">
-                    <label>Maximum rows to retrieve</label>
-                  </object>
-                  <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxTextCtrl" name="txtMaxRows">
-                    <value>100</value>
-                    <tooltip>Maximums rows to retrieve into output window; 0 = unlimited</tooltip>
+                  <object class="wxPanel" name="pnlPgAgent">
+                    <hidden>1</hidden>
+                    <object class="wxFlexGridSizer">
+                      <cols>2</cols>
+                      <vgap>5</vgap>
+                      <hgap>5</hgap>
+                      <growablecols>1</growablecols>
+                      <object class="sizeritem">
+                        <object class="wxStaticText" name="lblMaxRows">
+                          <label>Maximum rows to retrieve</label>
+                        </object>
+                        <flag>wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                        <border>4</border>
+                      </object>
+                      <object class="sizeritem">
+                        <object class="wxTextCtrl" name="txtMaxRows">
+                          <value>100</value>
+                          <tooltip>Maximums rows to retrieve into output window; 0 = unlimited</tooltip>
+                        </object>
+                        <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                        <border>4</border>
+                      </object>
+                    </object>
                   </object>
                   <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                   <border>4</border>
                 </object>
-                </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlMiscGuruHints">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>1</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>0</growablecols>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkSuppressHints">
-                    <label>Do not show guru hints; I'm one myself</label>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxCheckBox" name="chkResetHints">
-                    <label>Reset guru hints</label>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlMiscGuruHints">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>1</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>0</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkSuppressHints">
+                        <label>Do not show guru hints; I'm one myself</label>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxCheckBox" name="chkResetHints">
+                        <label>Reset guru hints</label>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
                 </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
-            </object>
-            <object class="sizeritem">
-			  <object class="wxPanel" name="pnlMiscLogging">
-				  <hidden>1</hidden>
-                <object class="wxFlexGridSizer">
-                  <cols>1</cols>
-                  <vgap>5</vgap>
-                  <hgap>5</hgap>
-                  <growablecols>0</growablecols>
-                <object class="sizeritem">
-                  <object class="wxStaticText" name="lblLogfile">
-                    <label>Logfile (%ID will be replaced with the Process ID)</label>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxFilePickerCtrl" name="pickerLogfile">
-                    <message>Select log file</message>
-                    <style>wxFLP_OPEN|wxFLP_USE_TEXTCTRL</style>
-                    <tooltip>Enter a filename to write application logs to.</tooltip>
-                  </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxRadioBox" name="radLoglevel">
-                    <label>Log Level</label>
-                    <content>
-                      <item>&amp;No logging</item>
-                      <item>&amp;Errors only</item>
-                      <item>Errors and N&amp;otices</item>
-                      <item>Errors, Notices, &amp;SQL</item>
-                      <item>&amp;Debug (not recommended for normal use)</item>
-                    </content>
-                    <selection>2</selection>
-                    <dimension>1</dimension>
-                    <style>wxRA_SPECIFY_COLS</style>
-                    <tooltip>Select the level of detail to record in the logfile.</tooltip>
+              <object class="sizeritem">
+                <object class="wxPanel" name="pnlMiscLogging">
+                  <hidden>1</hidden>
+                  <object class="wxFlexGridSizer">
+                    <cols>1</cols>
+                    <vgap>5</vgap>
+                    <hgap>5</hgap>
+                    <growablecols>0</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="lblLogfile">
+                        <label>Logfile (%ID will be replaced with the Process ID)</label>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxFilePickerCtrl" name="pickerLogfile">
+                        <message>Select log file</message>
+                        <style>wxFLP_OPEN|wxFLP_USE_TEXTCTRL</style>
+                        <tooltip>Enter a filename to write application logs to.</tooltip>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxRadioBox" name="radLoglevel">
+                        <label>Log Level</label>
+                        <content>
+                          <item>&amp;No logging</item>
+                          <item>&amp;Errors only</item>
+                          <item>Errors and N&amp;otices</item>
+                          <item>Errors, Notices, &amp;SQL</item>
+                          <item>&amp;Debug (not recommended for normal use)</item>
+                        </content>
+                        <selection>2</selection>
+                        <dimension>1</dimension>
+                        <style>wxRA_SPECIFY_COLS</style>
+                        <tooltip>Select the level of detail to record in the logfile.</tooltip>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
                   </object>
-                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-                  <border>4</border>
-                </object>
                 </object>
+                <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                <border>4</border>
               </object>
-              <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
-              <border>4</border>
             </object>
-          </object>
             <flag>wxEXPAND|wxALL</flag>
             <border>3</border>
           </object>
@@ -1308,5 +1316,8 @@
         <border>3</border>
       </object>
     </object>
+    <size>480,250d</size>
+    <title>Options</title>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
   </object>
-</resource>
+</resource>
\ No newline at end of file
